<?php declare(strict_types=1);

namespace Plugin\css_shipping\Migrations;

use JTL\Shop;
use JTL\Jtllog;


use JTL\Plugin\Migration;
use JTL\Update\IMigration;

/**
 * Class Migration20231102123301
 * @package Plugin\jtl_test\Migrations
 */
class Migration20231102123301 extends Migration implements IMigration {
	/**
	 * @inheritdoc
	 */

	public function columnExist($table, $field) {
		// false bedeutet das es die Spalte nicht gibt
		return $this->getDB()->query("Show columns from `" . $table . "` like '" . $field . "' ", 1);
	}

	public function tableExist($table) {
		// in Rows steht die Anzahl der Zeilen, false bedeutet das es die Tabelle nicht gibt
		$obj =  $this->getDB()->query("SHOW TABLE STATUS  like '" . $table . "'", 1);
		if($obj && (int) $obj->Rows == 0) {
			$o = $this->getDB()->query("SELECT COUNT(*) AS anzahl FROM " . $table . " WHERE 1",1);
			$obj->Rows = (int) $o->anzahl;
			return $obj;
		}
		return $obj;
	}


	public function up()    {

		if($this->columnExist('css_shippingOption','itemDependent') === false) {
			$this->execute("ALTER TABLE `css_shippingOption` ADD `itemDependent` CHAR(1) NOT NULL DEFAULT 'Y' ");
		}

		if($this->columnExist('css_shippingOption','bulkyGoods') === false) {
			$this->execute("ALTER TABLE `css_shippingOption` ADD `bulkyGoods` TEXT NOT NULL");
		}


		$aOptions = $this->getDB()->selectAll('css_shippingOption', [], []);
		if($aOptions !== null) {
			foreach($aOptions as $oOption) {
				if(!empty($oOption->zipCode)) {
					$oUpdate = new \stdClass();
					$obj = new \stdClass();
					$obj->zipCode	=  $oOption->zipCode;
					$obj->country	=  $oOption->country;
					$obj->mileageAllowance	=  $oOption->mileageAllowance;
					$obj->minMiles	=  $oOption->minMiles;
					$obj->maxMiles	=  $oOption->maxMiles;
					$obj->basicMilesPrice	=  $oOption->basicMilesPrice;
					$obj->basicMiles	=  $oOption->basicMiles;
					$oUpdate->bulkyGoods = \serialize([$obj]);
					$this->getDB()->update('css_shippingOption','id',(int) $oOption->id,$oUpdate);
				}
			}
		}
		$cache = Shop::Container()->getCache();
		$cache->flush('css_shipping_shippingOption');

		if($this->columnExist('css_shippingOption','basicMilesPrice') !== false) {

			$this->execute("
											ALTER TABLE `css_shippingOption`
											  DROP `basicMilesPrice`,
											  DROP `zipCode`,		
											  DROP `country`,		
											  DROP `mileageAllowance`,		
											  DROP `minMiles`,		
											  DROP `maxMiles`,		
											  DROP `basicMiles`
			  ");
		}

		if(($obj = $this->tableExist('css_shippingConfig')) && $obj->Rows > 0) {
			$this->execute("UPDATE css_shippingConfig set `version` = '2.0.7' ");
		} else {
			$this->execute(
				"INSERT INTO `css_shippingConfig` (`version`) VALUES ('2.0.7')"
			);
		}
	}



	/**
	 * @inheritdoc
	 */
	public function down() {
	}
}
